==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/CancelEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CancelEventArgsDescription } from "./CancelEventArgsDescription";
/**
 * @hidden
 */
var CancelEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(CancelEventArgsDescriptionMetadata, _super);
    function CancelEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CancelEventArgsDescriptionMetadata.b = function (a) {
        if (CancelEventArgsDescriptionMetadata.a == null) {
            CancelEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CancelEventArgsDescriptionMetadata.c(CancelEventArgsDescriptionMetadata.a);
        }
        if (a.k(CancelEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(CancelEventArgsDescriptionMetadata.a);
    };
    CancelEventArgsDescriptionMetadata.c = function (a) {
        a.item("Cancel", "Boolean");
    };
    CancelEventArgsDescriptionMetadata.d = function (a) {
        CancelEventArgsDescriptionMetadata.b(a);
        a.ac("CancelEventArgs", function () { return new CancelEventArgsDescription(); });
        a.ab("CancelEventArgs", CancelEventArgsDescriptionMetadata.a);
    };
    CancelEventArgsDescriptionMetadata.$t = markType(CancelEventArgsDescriptionMetadata, 'CancelEventArgsDescriptionMetadata');
    CancelEventArgsDescriptionMetadata.a = null;
    return CancelEventArgsDescriptionMetadata;
}(Base));
export { CancelEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/CancelEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CancelEventArgsDescription } from "./CancelEventArgsDescription";
/**
 * @hidden
 */
var CancelEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CancelEventArgsDescriptionMetadata, _super);
    function CancelEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CancelEventArgsDescriptionMetadata.b = function (a) {
        if (CancelEventArgsDescriptionMetadata.a == null) {
            CancelEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CancelEventArgsDescriptionMetadata.c(CancelEventArgsDescriptionMetadata.a);
        }
        if (a.k(CancelEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(CancelEventArgsDescriptionMetadata.a);
    };
    CancelEventArgsDescriptionMetadata.c = function (a) {
        a.item("Cancel", "Boolean");
    };
    CancelEventArgsDescriptionMetadata.d = function (a) {
        CancelEventArgsDescriptionMetadata.b(a);
        a.ae("CancelEventArgs", function () { return new CancelEventArgsDescription(); });
        a.ad("CancelEventArgs", CancelEventArgsDescriptionMetadata.a);
    };
    CancelEventArgsDescriptionMetadata.$t = markType(CancelEventArgsDescriptionMetadata, 'CancelEventArgsDescriptionMetadata');
    CancelEventArgsDescriptionMetadata.a = null;
    return CancelEventArgsDescriptionMetadata;
}(Base));
export { CancelEventArgsDescriptionMetadata };
